FakeUser class

Represents a fake user that can be used with the FakeSignInBackend to obtain a GoogleSignInAccount and simulate authentication.

Constructors

FakeUser({String? id, String? email, String? displayName, String? photoUrl, String? serverAuthCode, String? idToken, String? accessToken})
Any of the given parameters can be null.
const

Properties

accessToken → String?
Will be converted into GoogleSignInTokenData.accessToken.
final
displayName → String?
Will be converted into GoogleSignInUserData.displayName.
final
email → String?
Will be converted into GoogleSignInUserData.email.
final
hashCode → int
The hash code for this object.
no setterinherited
id → String?
Will be converted into GoogleSignInUserData.id.
final
idToken → String?
Will be converted into GoogleSignInTokenData.idToken.
final
photoUrl → String?
Will be converted into GoogleSignInUserData.photoUrl.
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
serverAuthCode → String?
Will be converted into GoogleSignInUserData.serverAuthCode.
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited