GoogleSignIn class
GoogleSignIn allows you to authenticate Google users.
Properties
-
authenticationEvents
→ Stream<
GoogleSignInAuthenticationEvent> -
Subscribe to this stream to be notified when sign in (authentication) and
sign out events happen.
no setter
-
Returns a client that can be used to request authorization tokens for
some user.
no setter
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
attemptLightweightAuthentication(
{bool reportAllExceptions = false}) → Future< GoogleSignInAccount?> ? - Attempts to sign in a previously authenticated user with minimal interaction.
-
authenticate(
{List< String> scopeHint = const <String>[]}) → Future<GoogleSignInAccount> - Starts an interactive sign-in process.
- Whether or not authorization calls that could show UI must be called from a user interaction, such as a button press, on the current platform.
-
disconnect(
) → Future< void> - Disconnects any currently authorized users from the app, revoking previous authorization.
-
initialize(
{String? clientId, String? serverClientId, String? nonce, String? hostedDomain}) → Future< void> - Initializes the sign in manager with the given configuration.
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
signOut(
) → Future< void> - Signs out any currently signed in user(s).
-
supportsAuthenticate(
) → bool - Whether or not the current platform supports the authenticate method.
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Static Properties
- instance → GoogleSignIn
-
Returns the single GoogleSignIn instance.
final