GoogleSignInAuthenticationEventSignIn class
A sign-in event, corresponding to an authentication flow completing successfully.
- Inheritance
-
- Object
- GoogleSignInAuthenticationEvent
- GoogleSignInAuthenticationEventSignIn
- Annotations
Constructors
- GoogleSignInAuthenticationEventSignIn({required GoogleSignInAccount user})
-
Creates an event for a successful sign in.
const
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- user → GoogleSignInAccount
-
The user that was authenticated.
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited