authorizationForScopes method
Requests client authorization tokens if they can be returned without user interaction.
If authorization would require user interaction, this returns null, in which case authorizeScopes should be used instead.
In rare cases, this can return tokens that are no longer valid. See clearAuthorizationToken for details.
Implementation
Future<GoogleSignInClientAuthorization?> authorizationForScopes(
List<String> scopes,
) async {
return _authorizeClient(scopes, promptIfUnauthorized: false);
}